@@ -9,9 +9,9 @@ class AllocineObject(object):
   def __repr__(self):
     return self.__unicode__()
 
-  def GetInfo(self, profile = "small"):
+  def getInfo(self, profile = "small"):
     url = "http://api.allocine.fr/rest/v3/%s?partner=%s&format=json&code=%s&profile=%s" % (self.__class__.__name__.lower(), PARTNER_CODE, self.code, profile)
     output = urllib2.urlopen(url).read()
     d = json.loads(output)
-    for k,v in d["movie"].items():
-      self.__dict__[k] = v
\ No newline at end of file
+    for k,v in d[self.__class__.__name__.lower()].items():
+      self.__dict__[k] = v
